Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(521)

Unified Diff: chrome/browser/storage_monitor/storage_monitor_chromeos.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/storage_monitor_chromeos.h
diff --git a/chrome/browser/storage_monitor/removable_device_notifications_chromeos.h b/chrome/browser/storage_monitor/storage_monitor_chromeos.h
similarity index 80%
rename from chrome/browser/storage_monitor/removable_device_notifications_chromeos.h
rename to chrome/browser/storage_monitor/storage_monitor_chromeos.h
index be745499bc268a9916ffc98c6ec66693e2914d1e..c5dd3592297154d27d61c8a3085acf5b9cd4d615 100644
--- a/chrome/browser/storage_monitor/removable_device_notifications_chromeos.h
+++ b/chrome/browser/storage_monitor/storage_monitor_chromeos.h
@@ -2,12 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// chromeos::RemovableDeviceNotificationsCros listens for mount point changes
// and notifies listeners about the addition and deletion of media
// devices.
#ifndef CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_CHROMEOS_H_
#define CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_CHROMEOS_H_
#if !defined(OS_CHROMEOS)
#error "Should only be used on ChromeOS."
@@ -24,13 +23,13 @@
namespace chromeos {
-class RemovableDeviceNotificationsCros
+class StorageMonitorCros
: public chrome::StorageMonitor,
- public base::RefCountedThreadSafe<RemovableDeviceNotificationsCros>,
+ public base::RefCountedThreadSafe<StorageMonitorCros>,
public disks::DiskMountManager::Observer {
public:
// Should only be called by browser start up code. Use GetInstance() instead.
- RemovableDeviceNotificationsCros();
+ StorageMonitorCros();
virtual void OnDiskEvent(disks::DiskMountManager::DiskEvent event,
const disks::DiskMountManager::Disk* disk) OVERRIDE;
@@ -63,13 +62,13 @@ class RemovableDeviceNotificationsCros
uint64 storage_size_in_bytes;
};
- friend class base::RefCountedThreadSafe<RemovableDeviceNotificationsCros>;
+ friend class base::RefCountedThreadSafe<StorageMonitorCros>;
// Mapping of mount path to removable mass storage info.
typedef std::map<std::string, StorageObjectInfo> MountMap;
// Private to avoid code deleting the object.
- virtual ~RemovableDeviceNotificationsCros();
+ virtual ~StorageMonitorCros();
// Checks existing mount points map for media devices. For each mount point,
// call CheckMountedPathOnFileThread() below.
@@ -91,9 +90,9 @@ class RemovableDeviceNotificationsCros
// Only accessed on the UI thread.
MountMap mount_map_;
- DISALLOW_COPY_AND_ASSIGN(RemovableDeviceNotificationsCros);
+ DISALLOW_COPY_AND_ASSIGN(StorageMonitorCros);
};
} // namespace chromeos
-#endif // CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_CHROMEOS_H_
+#endif // CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_CHROMEOS_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,12 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// chromeos::RemovableDeviceNotificationsCros listens for mount point changes
-// and notifies listeners about the addition and deletion of media
-// devices.
+// chromeos::StorageMonitorCros listens for mount point changes and notifies
+// listeners about the addition and deletion of media devices.
-#ifndef CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_CHROMEOS_H_
-#define CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_CHROMEOS_H_
+#ifndef CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_CHROMEOS_H_
+#define CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_CHROMEOS_H_
#if !defined(OS_CHROMEOS)
#error "Should only be used on ChromeOS."